# astrocalc

<!-- INFO BADGES -->  

[![](https://zenodo.org/badge/DOI/10.5281/zenodo.8014735.svg)](https://zenodo.org/doi/10.5281/zenodo.8014735) 

[![](https://img.shields.io/pypi/pyversions/astrocalc)](https://pypi.org/project/astrocalc/)  
[![](https://img.shields.io/pypi/v/astrocalc)](https://pypi.org/project/astrocalc/)  
[![](https://img.shields.io/github/license/thespacedoctor/astrocalc)](https://github.com/thespacedoctor/astrocalc)  
[![](https://img.shields.io/pypi/dm/astrocalc)](https://pypi.org/project/astrocalc/)  

<!-- STATUS BADGES -->  

[![](http://157.245.42.153:8080/buildStatus/icon?job=astrocalc%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/astrocalc/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=astrocalc%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/astrocalc/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/astrocalc@master/coverage.svg)](https://raw.githack.com/thespacedoctor/astrocalc/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/astrocalc/badge/?version=master)](https://astrocalc.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/astrocalc/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/astrocalc/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*perform common astronomy-related calculations, conversions and measurements within python scripts or from the command-line*.

Documentation for astrocalc is hosted by [Read the Docs](https://astrocalc.readthedocs.io/en/master/) (
[development version](https://astrocalc.readthedocs.io/en/develop/) and [master version](https://astrocalc.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/astrocalc). Please report any issues you find [here](https://github.com/thespacedoctor/astrocalc/issues).

## Features

* 

## How to cite astrocalc

If you use `astrocalc` in your work, please cite using the following BibTeX entry: 

```bibtex
@software{Young_astrocalc,
 author = {Young, David R.},
 doi = {10.5281/zenodo.8014735},
 license = {GPL-3.0-only},
 title = {{astrocalc. Perform common astronomy-related calculations, conversions and measurements within python scripts or from the command-line}},
 url = {https://zenodo.org/doi/10.5281/zenodo.8014735}
}
```

 

